traditional_chinese_word_dict = {
    # Main
    "application_name": "LoadDensity",
    # Widget
    "url": "URL: ",
    "test_time": "測試時間: ",
    "user_count": "測試使用者總數: ",
    "spawn_rate": "產生速率: ",
    "test_method": "測試 HTTP 方法: ",
    "start_button": "開始: ",
    "log": "日誌: ",
    # Test method
    "get": "GET",
    "post": "POST",
    "put": "PUT",
    "patch": "PATCH",
    "delete": "DELETE",
    "head": "HEAD",
    "options": "OPTIONS",
}
