# locust error
not_found_locust_error: str = "Locust not found"

# json error
cant_reformat_json_error: str = "can't reformat JSON: is the type correct?"
wrong_json_data_error: str = "can't parse JSON"
cant_find_json_error: str = "can't find JSON file"
cant_save_json_error: str = "can't save JSON file"
cant_generate_json_report: str = "can't generate JSON report"

# executor error
executor_data_error: str = "executor received invalid data"
executor_list_error: str = "executor received invalid data: list is empty or wrong type"

# HTML
html_generate_no_data_tag: str = "no records to generate HTML report"

# add command
add_command_exception_tag: str = "command value type must be a method or function"

# argparse
argparse_get_wrong_data: str = "argparse received invalid data"

# XML
cant_read_xml_error: str = "can't read XML"
xml_type_error: str = "XML type error"

# Callback executor
get_bad_trigger_method: str = "invalid trigger method: only kwargs and args accepted"
get_bad_trigger_function: str = "invalid trigger function: only functions in event_dict accepted"