english_word_dict = {
    # Main
    "application_name": "LoadDensity",
    # Widget
    "url": "URL",
    "test_time": "Test Time: ",
    "user_count": "User Count: ",
    "spawn_rate": "Spawn Rate: ",
    "test_method": "Test Method: ",
    "start_button": "Start: ",
    "log": "Log: ",
    # Test method
    "get": "GET",
    "post": "POST",
    "put": "PUT",
    "patch": "PATCH",
    "delete": "DELETE",
    "head": "HEAD",
    "options": "OPTIONS",
}
